@@ -1018,6 +1018,8 @@ void shell::errexit(int exitcode, const char *format, ...)
     format = buf;
 
     va_start(args, format);
+    if(!eq("*** ", format, 4))
+        fputs("*** ", stderr);
     vfprintf(stderr, format, args);
     fflush(stderr);
 
@@ -1388,15 +1390,6 @@ exit:
     return pid;
 }
 
-static unsigned detaches = 0;
-static shell::mainproc_t _entry = NULL;
-
-static void WINAPI _start(DWORD argc, LPSTR *argv)
-{
-    ++detaches;
-    (*_entry)(argc, argv);
-}
-
 static void exit_handler(void)
 {
     if(_exitproc) {
@@ -1433,13 +1426,11 @@ void shell::detach(mainproc_t entry)
 
     name = strdup(name);
 
-    if(detaches || entry == NULL)
+    if(entry == NULL)
         return;
 
-    _entry = entry;
-
     SERVICE_TABLE_ENTRY servicetable[] = {
-        {(LPSTR)name, &_start},
+        {(LPSTR)name, (LPSERVICE_MAIN_FUNCTION)entry},
         {NULL, NULL}
     };
 
@@ -2046,9 +2037,53 @@ void shell::log(const char *name, loglevel_t level, logmode_t mode, logproc_t ha
     case SYSTEM_LOG:
         ::openlog(name, LOG_CONS, LOG_DAEMON);
         return;
+    case SECURITY_LOG:
+        ::openlog(name, LOG_CONS, LOG_AUTHPRIV);
+        return;
     }
 }
 
+void shell::security(loglevel_t loglevel, const char *fmt, ...)
+{
+    assert(fmt != NULL && *fmt != 0);
+
+    char buf[256];
+    va_list args;
+    int level= LOG_ERR;
+
+    if(!errname || errmode == NONE || loglevel >= DEBUG0)
+        return;
+
+    va_start(args, fmt);
+    vsnprintf(buf, sizeof(buf), fmt, args);
+    va_end(args);
+
+    switch(loglevel) {
+    case INFO:
+        level = LOG_INFO;
+        break;
+    case NOTIFY:
+        level = LOG_NOTICE;
+        break;
+    case WARN:
+        level = LOG_WARNING;
+        break;
+    case ERR:
+        level = LOG_ERR;
+        break;
+    case FAIL:
+        level = LOG_CRIT;
+        break;
+    default:
+        level = LOG_ERR;
+    }
+
+    ::syslog(level | LOG_AUTHPRIV, "%s", buf);
+
+    if(level == LOG_CRIT)
+        cpr_runtime_error(buf);
+}
+
 void shell::log(loglevel_t loglevel, const char *fmt, ...)
 {
     assert(fmt != NULL && *fmt != 0);
@@ -2123,6 +2158,29 @@ void shell::log(const char *name, loglevel_t level, logmode_t mode, logproc_t ha
         errproc = handler;
 }
 
+void shell::security(loglevel_t loglevel, const char *fmt, ...)
+{
+    assert(fmt != NULL && *fmt != 0);
+
+    char buf[256];
+    va_list args;
+
+    if(!errname || errmode == NONE || loglevel >= DEBUG0)
+        return;
+
+    va_start(args, fmt);
+    vsnprintf(buf, sizeof(buf), fmt, args);
+    va_end(args);
+
+    if(fmt[strlen(fmt) - 1] == '\n')
+        fprintf(stderr, "%s: %s", errname, buf);
+    else
+        fprintf(stderr, "%s: %s\n", errname, buf);
+
+    if(loglevel == FAIL)
+        cpr_runtime_error(buf);
+}
+
 void shell::log(loglevel_t loglevel, const char *fmt, ...)
 {
     assert(fmt != NULL && *fmt != 0);
