@@ -96,6 +96,7 @@
 #if defined(_MSC_VER) || defined(WIN32) || defined(_WIN32)
 #define _MSWINDOWS_
 
+
 //#if defined(_WIN32_WINNT) && _WIN32_WINNT < 0x0501
 //#undef    _WIN32_WINNT
 //#define   _WIN32_WINNT 0x0501
@@ -178,40 +179,44 @@ typedef struct timespec {
 
 extern "C" {
 
-int cpr_setenv(const char *s, const char *v, int p);
+    #define SERVICE_MAIN(id, argc, argv) void WINAPI service_##id(DWORD argc, LPSTR *argv)
 
-inline int setenv(const char *s, const char *v, int overwrite)
-    {return cpr_setenv(s, v, overwrite);};
+    typedef LPSERVICE_MAIN_FUNCTION cpr_service_t;
 
-inline void sleep(int seconds)
-    {::Sleep((seconds * 1000l));};
+    __EXPORT int cpr_setenv(const char *s, const char *v, int p);
 
-inline void pthread_exit(void *p)
-    {_endthreadex((DWORD)p);};
+    inline int setenv(const char *s, const char *v, int overwrite)
+        {return cpr_setenv(s, v, overwrite);};
 
-inline pthread_t pthread_self(void)
-    {return (pthread_t)GetCurrentThreadId();};
+    inline void sleep(int seconds)
+        {::Sleep((seconds * 1000l));};
 
-inline int pthread_mutex_init(pthread_mutex_t *mutex, void *x)
-    {InitializeCriticalSection(mutex); return 0;};
+    inline void pthread_exit(void *p)
+        {_endthreadex((DWORD)p);};
 
-inline void pthread_mutex_destroy(pthread_mutex_t *mutex)
-    {DeleteCriticalSection(mutex);};
+    inline pthread_t pthread_self(void)
+        {return (pthread_t)GetCurrentThreadId();};
 
-inline void pthread_mutex_lock(pthread_mutex_t *mutex)
-    {EnterCriticalSection(mutex);};
+    inline int pthread_mutex_init(pthread_mutex_t *mutex, void *x)
+        {InitializeCriticalSection(mutex); return 0;};
 
-inline void pthread_mutex_unlock(pthread_mutex_t *mutex)
-    {LeaveCriticalSection(mutex);};
+    inline void pthread_mutex_destroy(pthread_mutex_t *mutex)
+        {DeleteCriticalSection(mutex);};
 
-inline char *strdup(const char *s)
-    {return _strdup(s);};
+    inline void pthread_mutex_lock(pthread_mutex_t *mutex)
+        {EnterCriticalSection(mutex);};
 
-inline int stricmp(const char *s1, const char *s2)
-    {return _stricmp(s1, s2);};
+    inline void pthread_mutex_unlock(pthread_mutex_t *mutex)
+        {LeaveCriticalSection(mutex);};
 
-inline int strnicmp(const char *s1, const char *s2, size_t l)
-    {return _strnicmp(s1, s2, l);};
+    inline char *strdup(const char *s)
+        {return _strdup(s);};
+
+    inline int stricmp(const char *s1, const char *s2)
+        {return _stricmp(s1, s2);};
+
+    inline int strnicmp(const char *s1, const char *s2, size_t l)
+        {return _strnicmp(s1, s2, l);};
 };
 
 #elif defined(__PTH__)
@@ -286,6 +291,7 @@ typedef char *caddr_t;
 #include <stdio.h>
 #define snprintf _snprintf
 #define vsnprintf _vsnprintf
+#define alloca(x) _alloca(x)
 #endif
 
 #else
@@ -398,7 +404,7 @@ extern "C" __EXPORT void cpr_memswap(void *mem1, void *mem2, size_t size);
  * @return memory allocated from heap.
  */
 inline void *operator new(size_t size)
-    {return cpr_memalloc(size);};
+    {return cpr_memalloc(size);}
 
 /**
  * Our generic new array operator.  Uses our heap memory allocator.
@@ -406,7 +412,7 @@ inline void *operator new(size_t size)
  * @return memory allocated from heap.
  */
 inline void *operator new[](size_t size)
-    {return cpr_memalloc(size);};
+    {return cpr_memalloc(size);}
 #endif
 
 #ifndef _UCOMMON_EXTENDED_
@@ -419,7 +425,7 @@ inline void *operator new[](size_t size)
  * @return memory we placed object array.
  */
 inline void *operator new[](size_t size, caddr_t address)
-    {return cpr_memassign(size, address, size);};
+    {return cpr_memassign(size, address, size);}
 
 /**
  * A placement new array operator where we know the allocated size.  We
@@ -431,7 +437,7 @@ inline void *operator new[](size_t size, caddr_t address)
  * @return memory we placed object array.
  */
 inline void *operator new[](size_t size, caddr_t address, size_t known)
-    {return cpr_memassign(size, address, known);};
+    {return cpr_memassign(size, address, known);}
 #endif
 
 /**
@@ -502,6 +508,16 @@ extern "C" __EXPORT void __cxa_pure_virtual(void);
 #endif
 #endif
 
+#ifndef PROGRAM_MAIN
+#define PROGRAM_MAIN(argc, argv)    extern "C" int main(int argc, char **argv)
+#define PROGRAM_EXIT(code)          return code
+#endif
+
+#ifndef SERVICE_MAIN
+#define SERVICE_MAIN(id, argc, argv)    void service_##id(int argc, char **argv)
+typedef void (*cpr_service_t)(int argc, char **argv);
+#endif
+
 #include <assert.h>
 #ifdef  DEBUG
 #define crit(x, text)   assert(x)
