@@ -84,6 +84,7 @@
 #define _UCOMMON_UCOMMON_H_
 #include <ucommon/platform.h>
 #include <ucommon/atomic.h>
+#include <ucommon/generics.h>
 #include <ucommon/object.h>
 #include <ucommon/protocols.h>
 #include <ucommon/string.h>
@@ -101,6 +102,7 @@
 #include <ucommon/bitmap.h>
 #include <ucommon/socket.h>
 #include <ucommon/thread.h>
+#include <ucommon/containers.h>
 #include <ucommon/fsys.h>
 #include <ucommon/buffer.h>
 #include <ucommon/shell.h>
